pro ppt_make_circle_draw_list,Event
	;
	;	uses designated image header,
	;	circle color, size, thickness properties,
	;	and star selection criteria
	;
	;	to create structure of circles on heap
	;
	;	these can drive display on provisional image
	;	or, later, to generate the DS9 region file
	;
	;	20200218 DPC - original for vectors
	;	20200818 DPC - modified for upper limit circles
	;
	WIDGET_CONTROL, Event.top, GET_UVALUE=PTR
	;
	;	get the image header astrometry
	;
	if((*PTR).image_read_flag ne 1L) then begin
		zprint, Event, 'No Image Read. Must read an image'
		goto, skip_to_end
	endif
	;
	extast, (*(*PTR).header_ptr), astr
	;
	;	don't need to collect selection criteria, as tab 2 did that
	;
	n_reject = (*PTR).n_reject
	if(n_reject eq 0) then begin
		zprint, Event, 'No stars have upper limits in this POLCAT file. Skipping circle creation.'
		goto, skip_to_end
	endif
	ind_reject = (*PTR).ind_reject
	;
	;	create space for structure of information for each upper limit circle
	;
	circle = {circ_no:	   0L,$		;	serial number of this circle
			  ;
			  x_cen:	0.0d0,$		; 	star x center in image
			  y_cen:	0.0d0,$		;   star y center in image
			  ra_cen:	0.0d0,$		;   star RA in deg
			  dec_cen:	0.0d0,$		; 	star Dec in deg
			  ;
			  circ_radius:0.0d0, $	;	in pixels of the image
			  circ_color:	'',$	; 	color name of circle
			  circ_thick:	0L $	;	thickness value of circle
			  }
	;
	(*PTR).circles_ptr = PTR_NEW(REPLICATE(circle,n_reject))
	;
	;	set up the common values
	;
	;
	;	length, color, and thickness info
	;

	thick_scale = (*PTR).circle_thicknesses[(*PTR).circle_thickness_index]
	;
	length_scale_text = (*PTR).circle_radii[(*PTR).circle_radius_index]	; in pixels of the image
	;
	parts = STRSPLIT(length_scale_text,' ',/extract,count=count)
	if(count ne 2) then begin
		zprint, Event, 'ERROR in parsing length scale in make_circle_draw_list. Stopping'
		stop
	endif
	length_scale = fix(parts[0])		; pick off the number of pixels
	;
	;	for each selected star, populate the structure fields
	;
	for i = 0, n_reject-1 do begin
		;
		jj = ind_reject[i]		; the index into the polcat database
		;
		(*(*PTR).circles_ptr)[i].circ_no = i+1
		(*(*PTR).circles_ptr)[i].ra_cen = (*(*PTR).polcat_data).s[jj].RA_deg
		(*(*PTR).circles_ptr)[i].dec_cen = (*(*PTR).polcat_data).s[jj].Dec_deg
		;
		;	x, y star location of center in image
		;
		a = (*(*PTR).polcat_data).s[jj].RA_deg
		d = (*(*PTR).polcat_data).s[jj].Dec_deg
		;
		ad2xy, a, d, astr, xcen, ycen
		;
		(*(*PTR).circles_ptr)[i].x_cen = xcen
		(*(*PTR).circles_ptr)[i].y_cen = ycen
		;
		this_sp = (*(*PTR).polcat_data).s[jj].sp
		this_praw = sqrt((*(*PTR).polcat_data).s[jj].Q^2 + (*(*PTR).polcat_data).s[jj].U^2)
		this_psnr = this_praw / this_sp
		this_mH = (*(*PTR).polcat_data).s[jj].H_mag
		;
		;	assign to either Low-P or Faint groups
		;
		LowP_flag = 0
		Faint_flag = 0
		;
		if(this_mH le (*PTR).max_mag and this_psnr lt (*PTR).min_psnr) then begin
			LowP_flag = 1
			;
			;	which class of LowP?
			;
			LowP_value = -alog(this_psnr)/alog(2.)
			;
			LowP_type = 'low'
			if(LowP_value gt +1.) then LowP_type = 'med'
			if(LowP_value gt +3.) then LowP_type = 'high'
		endif else begin
			LowP_type = 'none'
		endelse
		;
		if(this_mH gt (*PTR).max_mag or this_sp gt (*PTR).max_sp) then Faint_flag = 1
		;
		; these need to be convolved against the settings and colors
		;
		(*(*PTR).circles_ptr)[i].circ_radius = length_scale
		(*(*PTR).circles_ptr)[i].circ_thick = thick_scale
		;
		;	all else is color
		;
		;	start by assigning to the faint color, then see if other flags are set
		;
		(*(*PTR).circles_ptr)[i].circ_color = (*PTR).color_names[(*PTR).color_faint]	; as a name
		;
		;	test for split by Low-P vs Faint
		;
		if( (*PTR).split_LowP_Faint_flag eq 1) then begin
			;
			;	by -log_2(PSNR) - which zone?
			;
			case LowP_type of
				'low': (*(*PTR).circles_ptr)[i].circ_color = (*PTR).color_names[(*PTR).color_LowP_low]
				'med': (*(*PTR).circles_ptr)[i].circ_color = (*PTR).color_names[(*PTR).color_LowP_med]
				'high': (*(*PTR).circles_ptr)[i].circ_color = (*PTR).color_names[(*PTR).color_LowP_high]
				'none': ; do nothing, this is a faint assignment, already colored
			endcase
			;
		endif
		;
		;	all values loaded
		;	next vector
		;
	endfor

	;
skip_to_end:
;
end