pro ppt_make_vector_draw_list,Event
	;
	;	uses designated image header,
	;	vector color, size, thickness properties,
	;	and star selection criteria
	;
	;	to create structure of vectors on heap
	;
	;	these can drive display on provisional image
	;	or, later, to generate the DS9 region file
	;
	;	20200218 DPC
	;
	WIDGET_CONTROL, Event.top, GET_UVALUE=PTR
	;
	;	get the image header astrometry
	;
	if((*PTR).image_read_flag ne 1L) then begin
		zprint, Event, 'No Image Read. Must read an image'
		goto, skip_to_end
	endif
	;
	extast, (*(*PTR).header_ptr), astr
	;
	;	don't need to collect selection criteria, as tab 2 did that
	;
	n_select = (*PTR).n_select
	if(n_select eq 0) then begin
		zprint, Event, 'No stars meet selection critia. Skipping vector creation.'
		goto, skip_to_end
	endif
	ind_select = (*PTR).ind_select
	;
	;	create space for structure of information for each vector
	;
	vector = {vec_no:	   0L,$		;	serial number of this vector
			  length_mode: '',$		;	'uniform','log, or 'variable'
			  color_mode:  '',$		;	'uniform' or 'variable'
			  thick_mode:  '',$		;	'uniform' or 'variable'
			  ;
			  x_cen:	0.0d0,$		; 	star x center in image
			  y_cen:	0.0d0,$		;   star y center in image
			  ra_cen:	0.0d0,$		;   star RA in deg
			  dec_cen:	0.0d0,$		; 	star Dec in deg
			  ;
			  x_0:		0.0d0,$		;	starting x value in image
			  y_0:		0.0d0,$		;	starting y value in image
			  ra_0:		0.0d0,$		;	starting RA in deg
			  dec_0:	0.0d0,$		; 	starting Dec in deg
			  ;
			  x_1:		0.0d0,$		; 	ending x value in image
			  y_1:		0.0d0,$		; 	ending y value in image
			  ra_1:		0.0d0,$		;	ending RA in deg
			  dec_1:	0.0d0,$		;	ending Dec in deg
			  ;
			  vec_length:0.0d0, $	;	in pixels of the image
			  vec_color:	'',$	; 	color name of vector
			  vec_thick:	0L $	;	thickness value of vector
			  }
	;
	(*PTR).vectors_ptr = PTR_NEW(REPLICATE(vector,n_select+1))	; the +1 is the reference vector
	;
	;	set up the common values
	;
	;
	;	length, color, and thickness info
	;
	if((*PTR).uniform_length_flag eq 0L and $
	   (*PTR).pol_length_flag eq 1L and $
	   (*PTR).pol_log_flag eq 0L) then begin
	     length_mode = 'variable'
	endif else begin
	  if((*PTR).uniform_length_flag eq 1L and $
       (*PTR).pol_length_flag eq 0L and $
       (*PTR).pol_log_flag eq 0L) then begin 
        length_mode = 'uniform'
    endif else begin
		  length_mode = 'log'
		endelse
	endelse
	;
	if((*PTR).color_uniform_flag eq 0L and (*PTR).color_PSNR_flag eq 1L) then begin
		color_mode = 'variable'
	endif else begin
		color_mode = 'uniform'
	endelse
	;
	thick_mode = 'uniform'		; for now
	thick_scale = (*PTR).vector_thicknesses[(*PTR).vector_thickness_index]
	;
	length_scale_text = (*PTR).vector_lengths[(*PTR).vector_length_index]	; in pixels of the image
	parts = STRSPLIT(length_scale_text,' ',/extract,count=count)
	if(count ne 2) then begin
		zprint, Event, 'ERROR in parsing length scale in make_vector_draw_list. Stopping'
		stop
	endif
	length_scale = fix(parts[0])		; pick off the number of pixels
	;
	;	for each selected star/vector, populate the structure fields
	;
	for i = 0, n_select-1 do begin
		;
		jj = ind_select[i]		; the index into the polcat database
		;
		(*(*PTR).vectors_ptr)[i].vec_no = i+1
		(*(*PTR).vectors_ptr)[i].ra_cen = (*(*PTR).polcat_data).s[jj].RA_deg
		(*(*PTR).vectors_ptr)[i].dec_cen = (*(*PTR).polcat_data).s[jj].Dec_deg
		;
		;	x, y star location of center in image
		;
		a = (*(*PTR).polcat_data).s[jj].RA_deg
		d = (*(*PTR).polcat_data).s[jj].Dec_deg
		;
		ad2xy, a, d, astr, xcen, ycen
		;
		(*(*PTR).vectors_ptr)[i].x_cen = xcen
		(*(*PTR).vectors_ptr)[i].y_cen = ycen
		;
		this_p = (*(*PTR).polcat_data).s[jj].p
		this_sp = (*(*PTR).polcat_data).s[jj].sp
		this_praw = sqrt((*(*PTR).polcat_data).s[jj].Q^2 + (*(*PTR).polcat_data).s[jj].U^2)
		this_psnr = this_praw / this_sp
		;
		this_pa = (*(*PTR).polcat_data).s[jj].PA_deg
		;
		ca = cos(this_pa*1.745e-2)
		sa = sin(this_pa*1.745e-2)
		;
		(*(*PTR).vectors_ptr)[i].length_mode = length_mode
		;
		(*(*PTR).vectors_ptr)[i].color_mode = color_mode
		;
		(*(*PTR).vectors_ptr)[i].thick_mode = thick_mode
		;
		CASE length_mode OF
		  'uniform': begin
			           (*(*PTR).vectors_ptr)[i].vec_length = length_scale * 1.0	; assume 1% polarization
                 end
		 'variable': begin
			           (*(*PTR).vectors_ptr)[i].vec_length = length_scale * this_p	; scale by percentage polarization
			           end
          'log': begin
                  (*(*PTR).vectors_ptr)[i].vec_length = length_scale * (0.0 > (1.0 + alog10(this_p))) ; scale by log(P) with offset
                 end
		ENDCASE
		;
		if(color_mode eq 'uniform') then begin
			(*(*PTR).vectors_ptr)[i].vec_color = (*PTR).color_names[(*PTR).color_uniform]	; as a name
		endif else begin
			;
			;	by PSNR - which psnr boundary? (2, 3, 5, 7, 10)
			;
			(*(*PTR).vectors_ptr)[i].vec_color = (*PTR).color_names[(*PTR).colors_PSNR[0]]
			if(this_psnr ge 2.0) then begin
				(*(*PTR).vectors_ptr)[i].vec_color = (*PTR).color_names[(*PTR).colors_PSNR[1]]
			endif
			if(this_psnr ge 3.0) then begin
				(*(*PTR).vectors_ptr)[i].vec_color = (*PTR).color_names[(*PTR).colors_PSNR[2]]
			endif
			if(this_psnr ge 5.0) then begin
				(*(*PTR).vectors_ptr)[i].vec_color = (*PTR).color_names[(*PTR).colors_PSNR[3]]
			endif
			if(this_psnr ge 7.0) then begin
				(*(*PTR).vectors_ptr)[i].vec_color = (*PTR).color_names[(*PTR).colors_PSNR[4]]
			endif
			if(this_psnr ge 10.0) then begin
				(*(*PTR).vectors_ptr)[i].vec_color = (*PTR).color_names[(*PTR).colors_PSNR[5]]
			endif
		endelse
		;
		if(thick_mode eq 'uniform') then begin
			(*(*PTR).vectors_ptr)[i].vec_thick = thick_scale
		endif else begin
			zprint,Event,'non-uniform vector thicknesses not currently supported'
		endelse
		;
		(*(*PTR).vectors_ptr)[i].x_0 = (*(*PTR).vectors_ptr)[i].x_cen - (*(*PTR).vectors_ptr)[i].vec_length * sa
		(*(*PTR).vectors_ptr)[i].y_0 = (*(*PTR).vectors_ptr)[i].y_cen + (*(*PTR).vectors_ptr)[i].vec_length * ca
		(*(*PTR).vectors_ptr)[i].x_1 = (*(*PTR).vectors_ptr)[i].x_cen + (*(*PTR).vectors_ptr)[i].vec_length * sa
		(*(*PTR).vectors_ptr)[i].y_1 = (*(*PTR).vectors_ptr)[i].y_cen - (*(*PTR).vectors_ptr)[i].vec_length * ca
		;
		;	 RA, Decs of endpoints
		;
		x_0 = (*(*PTR).vectors_ptr)[i].x_0
		y_0 = (*(*PTR).vectors_ptr)[i].y_0
		xy2ad, x_0, y_0, astr, a_0, d_0
		;
		x_1 = (*(*PTR).vectors_ptr)[i].x_1
		y_1 = (*(*PTR).vectors_ptr)[i].y_1
		xy2ad, x_1, y_1, astr, a_1, d_1
		;
		(*(*PTR).vectors_ptr)[i].ra_0 = a_0
		(*(*PTR).vectors_ptr)[i].ra_1 = a_1
		(*(*PTR).vectors_ptr)[i].dec_0 = d_0
		(*(*PTR).vectors_ptr)[i].dec_1 = d_1
		;
		;	all values loaded
		;	next vector
		;
	endfor
	;
	;	load the reference vector entry
	;
	xfrac = 0.8	; 80% along x
	yfrac = 0.1	; 10% along y
	;
	nx = SXPAR((*(*PTR).header_ptr),'NAXIS1')
	ny = SXPAR((*(*PTR).header_ptr),'NAXIS2')
	;
	xcen = xfrac * nx
	ycen = yfrac * ny
	;
	i = n_select
	;
	(*(*PTR).vectors_ptr)[i].vec_no = -1	; to signify reference
	(*(*PTR).vectors_ptr)[i].x_cen = xcen
	(*(*PTR).vectors_ptr)[i].y_cen = ycen
	;
	xy2ad, xcen, ycen, astr, RA_deg, Dec_deg
	;
	(*(*PTR).vectors_ptr)[i].ra_cen = (*(*PTR).polcat_data).s[jj].RA_deg
	(*(*PTR).vectors_ptr)[i].dec_cen = (*(*PTR).polcat_data).s[jj].Dec_deg
	;
	this_ref_label = (*PTR).reference_lengths[(*PTR).reference_length_index]
	case this_ref_label of
		'0.5%': ref_len = 0.5
		'1.0%': ref_len = 1.0
		'1.5%': ref_len = 1.5
		'2.0%': ref_len = 2.0
		'2.5%': ref_len = 2.5
		'3.0%': ref_len = 3.0
		'4.0%': ref_len = 4.0
		'5.0%': ref_len = 5.0
		'No Ref. Vec.': ref_len = 0.0
	endcase
	;
	this_pa = 90.0
	;
	ca = cos(this_pa*1.745e-2)
	sa = sin(this_pa*1.745e-2)
	;
	CASE length_mode OF
      'uniform': begin
                 (*(*PTR).vectors_ptr)[i].vec_length = length_scale * 1.0 ; assume 1% polarization
                 end
     'variable': begin
                 (*(*PTR).vectors_ptr)[i].vec_length = length_scale * ref_len  ; scale by percentage polarization
                 end
          'log': begin
                  (*(*PTR).vectors_ptr)[i].vec_length = length_scale * (0.0 > (1.0 + alog10(ref_len))) ; scale by log(P) with offset
                 end
  ENDCASE
	;(*(*PTR).vectors_ptr)[i].vec_length = length_scale * ref_len
	;
	(*(*PTR).vectors_ptr)[i].x_0 = (*(*PTR).vectors_ptr)[i].x_cen - (*(*PTR).vectors_ptr)[i].vec_length * sa
	(*(*PTR).vectors_ptr)[i].y_0 = (*(*PTR).vectors_ptr)[i].y_cen + (*(*PTR).vectors_ptr)[i].vec_length * ca
	(*(*PTR).vectors_ptr)[i].x_1 = (*(*PTR).vectors_ptr)[i].x_cen + (*(*PTR).vectors_ptr)[i].vec_length * sa
	(*(*PTR).vectors_ptr)[i].y_1 = (*(*PTR).vectors_ptr)[i].y_cen - (*(*PTR).vectors_ptr)[i].vec_length * ca
	;
	;	 RA, Decs of endpoints
	;
	x_0 = (*(*PTR).vectors_ptr)[i].x_0
	y_0 = (*(*PTR).vectors_ptr)[i].y_0
	xy2ad, x_0, y_0, astr, a_0, d_0
	;
	x_1 = (*(*PTR).vectors_ptr)[i].x_1
	y_1 = (*(*PTR).vectors_ptr)[i].y_1
	xy2ad, x_1, y_1, astr, a_1, d_1
	;
	(*(*PTR).vectors_ptr)[i].ra_0 = a_0
	(*(*PTR).vectors_ptr)[i].ra_1 = a_1
	(*(*PTR).vectors_ptr)[i].dec_0 = d_0
	(*(*PTR).vectors_ptr)[i].dec_1 = d_1
	;
	(*(*PTR).vectors_ptr)[i].vec_color = (*PTR).color_names[(*PTR).color_reference]
	(*(*PTR).vectors_ptr)[i].vec_thick = thick_scale
	;
skip_to_end:
;
end