function PPT_Read_POLCAT, file_path
;
;	reads a POLCAT pointed to by the pathname into a structure
;
;	DPC	20110107
;		20110505	added support for POLCAT header parsing
;		20110831	updated to include UF field
;		20120220	updated to include GPIPS photometry
;
;file_in = dialog_pickfile(title='Select POLCAT')
;
nlines = FILE_LINES(file_path)
;
openr, lu_in, file_path, /GET_LUN
;
;	Save Header for parsing
;
nheader = 0L
header = strarr(1)
for i = 0, nlines-1 do begin
	line = ''
	readf, lu_in, line, format='(a)'
	if(STRPOS( line, ';') eq 0) then begin
		if(nheader eq 0) then begin
			;
			;	check string length, if more than 70 characters, issue
			;		continue
			;
			header_line = STRMID(line,2)
			if(STRLEN(header_line) gt 69) then begin
				first_line = STRMID(header_line,0,69) + "'"+'&'
				second_line = 'CONTINUE'+"'"+STRMID(header_line,69)
				;
				header = first_line
				header = [header, second_line]
			endif else begin
				header = [STRMID(line,2)]
			endelse
		endif else begin
			header_line = STRMID(line,2)
			if(STRLEN(header_line) gt 69) then begin
				first_line = STRMID(header_line,0,69) + "'"+'&'
				second_line = 'CONTINUE'+"'"+STRMID(header_line,69)
				;
				header = [header, first_line]
				header = [header, second_line]
			endif else begin
				header = [header, STRMID(line,2)]
			endelse
		endelse
		nheader++
	endif
endfor
;
FREE_LUN, lu_in
;
;	parse the header
;
jd_mean = sxpar(header, 'JDMEAN*', COUNT=jcount,/SILENT)
if(jcount gt 0) then begin
	;
	;	OK, header is present, parse it
	;
	history 	= sxpar(header, 'HISTORY',/SILENT)
	nhist = N_ELEMENTS(history)
	;
	group_name 	= sxpar(header, 'GP_GROUP',/SILENT)
	dir_name 	= sxpar(header, 'GPOBSRUN',/SILENT)
	process_dt 	= sxpar(header, 'DTM_PPOL',/SILENT)
	ppol_ver    = sxpar(header, 'PPOL_VER',/SILENT)
	;
	p_inst_file = sxpar(header, 'PINST_FL',/SILENT)
	datestmp 	= sxpar(header, 'DATESTMP',/SILENT)
	p_inst_blk	= sxpar(header, 'PINST_BK',/SILENT)
	blk_end_yr	= sxpar(header, 'END_YR',/SILENT)
	pa_offset	= sxpar(header, 'PA_OFF',/SILENT)
	s_pa_offset	= sxpar(header, 'S_PA_OFF',/SILENT)
	pol_effic	= sxpar(header, 'P_EFFIC',/SILENT)
	s_pol_effic	= sxpar(header, 'S_P_EFF',/SILENT)
	;
	;	the next block of variables are specific to
	;	the group. These show up only once for a single
	;	group POLCAT, but in multiple copies for a
	;	meta-group. This is signalled by value of the
	;	NGROUPS keyword
	;
	ngroups 	= sxpar(header, 'NGROUPS',/SILENT)
	if(ngroups eq 1) then meta_flag = 0 else meta_flag = 1
	if(meta_flag eq 0) then begin
		;
		;	single group POLCAT
		;
		image_d 	= sxpar(header, 'IMAG_D01',/SILENT)
		image_0 	= sxpar(header, 'IMAG_A01',/SILENT)
		image_n 	= sxpar(header, 'IMAG_Z01',/SILENT)
		this_group	= sxpar(header, 'GRPNAM01',/SILENT)
		;
		jd_mean		= sxpar(header, 'JDMEAN01',/SILENT)
		fwhm_av 	= sxpar(header, 'FWHMAV01',/SILENT)
		fwhm_cor	= sxpar(header, 'FWHMCR01',/SILENT)
		n_in_grp 	= sxpar(header, 'NINGRP01',/SILENT)
		n_use_0 	= sxpar(header, 'NUSE0_01',/SILENT)
		;
		mean_sky 	= sxpar(header, 'AV_SKY01',/SILENT)
		skynoise 	= sxpar(header, 'SKNOIS01',/SILENT)
		fieldpol 	= sxpar(header, 'FLDPOL01',/SILENT)
		noise_fp 	= sxpar(header, 'S_FLPL01',/SILENT)
	endif else begin
		;
		;	meta-group POLCAT, vectors for each
		;	of the group parameters
		;
		image_d 	= sxpar(header, 'IMAG_D*',/SILENT)
		image_0 	= sxpar(header, 'IMAG_A*',/SILENT)
		image_n 	= sxpar(header, 'IMAG_Z*',/SILENT)
		this_group	= sxpar(header, 'GRPNAM*',/SILENT)
		;
		jd_mean		= sxpar(header, 'JDMEAN*',/SILENT)
		fwhm_av 	= sxpar(header, 'FWHMAV*',/SILENT)
		fwhm_cor	= sxpar(header, 'FWHMCR*',/SILENT)
		n_in_grp 	= sxpar(header, 'NINGRP*',/SILENT)
		n_use_0 	= sxpar(header, 'NUSE0_*',/SILENT)
		;
		mean_sky 	= sxpar(header, 'AV_SKY*',/SILENT)
		skynoise 	= sxpar(header, 'SKNOIS*',/SILENT)
		fieldpol 	= sxpar(header, 'FLDPOL*',/SILENT)
		noise_fp 	= sxpar(header, 'S_FLPL*',/SILENT)
	endelse
	;
	;	create the return structure
	;
	pol_head = {meta_flag: 		meta_flag, $
				ngroups:		ngroups, $
				group_name: 	group_name, $
				dir_name: 		dir_name, $
				process_dt: 	process_dt, $
				ppol_ver: 		ppol_ver, $
				;
				p_inst_file:	p_inst_file, $
				datestmp: 		datestmp, $
				p_inst_blk:		p_inst_blk, $
				blk_end_yr:		blk_end_yr, $
				pa_offset:		pa_offset, $
				s_pa_offset:	s_pa_offset, $
				pol_effic:		pol_effic, $
				s_pol_effic:	s_pol_effic, $
				;
				image_d: 		image_d, $
				image_0: 		image_0, $
				image_n:	 	image_n, $
				this_group:		this_group, $
				;
				jd_mean:		jd_mean, $
				fwhm_av: 		fwhm_av, $
				fwhm_cor:		fwhm_cor, $
				n_in_grp: 		n_in_grp, $
				n_use_0: 		n_use_0, $
				;
				mean_sky: 		mean_sky, $
				skynoise: 		skynoise, $
				fieldpol: 		fieldpol, $
				noise_fp: 		noise_fp $
				}
endif else begin
	pol_head = {error: 'no header present'}
endelse
;
nentries = nlines - nheader
;
entry = {num: 0L, id: 0L, desig: '', X_img:0.0d0, Y_img: 0.0d0, X_det: 0, Y_det: 0, RA_deg: 0.0d0, $
			Dec_deg: 0.0d0, H_mag: 0.0d0, sHmag: 0.0d0, sPhot: 0.0d0, Sky_cts: 0.0d0, P: 0.0d0, $
			sP: 0.0d0, PA_deg: 0.0d0, GPA_deg: 0.0d0, sPA: 0.0d0, Q: 0.0d0, sQ: 0.0d0, U: 0.0d0, $
			sU: 0.0d0, nHWP: 0, UF: 0, ID_2Mass: 0L, desig_2mass: '', RA_2mass: 0.0d0, Dec_2mass: 0.0d0, $
			J_2mass: 0.0d0, sJ2mass:0.0d0, H_2mass: 0.0d0, sH2mass: 0.0d0, K_2mass: 0.0d0, $
			sK2mass: 0.0d0, b36mag: 0.0d0, e_b36mag: 0.0d0, b45mag: 0.0d0, e_b45mag: 0.0d0, b58mag: 0.0d0, $
			e_b58mag: 0.0d0, b80mag: 0.0d0, e_b80mag: 0.0d0}
;
s = REPLICATE( entry, nentries )
;
openr, lu_in, file_path, /GET_LUN
;
;	skip past the header
;
line = ''
for iskip = 0, nheader-1 do readf, lu_in, line, format='(a)'
;
i = 0L
WHILE ~EOF(lu_in) do begin
	readf, lu_in, line, format='(a)'
	ind = STRPOS(line, ';')
	if(ind ne -1) then goto, loop_end
	;
	c = STRSPLIT(line, ' ',/REGEX, /EXTRACT)
	nc = N_ELEMENTS(c)
	;
	j=0
	s[i].num = c[j]
	s[i].id  = c[++j]
	s[i].desig = c[++j]
	;
	s[i].X_img = double(c[++j])
	s[i].Y_img = double(c[++j])
	s[i].X_det = float(c[++j])
	s[i].Y_det = float(c[++j])
	s[i].RA_deg = double(c[++j])
	s[i].Dec_deg = double(c[++j])
	s[i].H_mag = double(c[++j])
	s[i].sHmag = double(c[++j])
	s[i].sPhot = double(c[++j])
	s[i].Sky_cts = double(c[++j])
	;
	s[i].P = double(c[++j])
	s[i].sP = double(c[++j])
	s[i].PA_deg = double(c[++j])
	s[i].GPA_deg = double(c[++j])
	s[i].sPA = double(c[++j])
	s[i].Q = double(c[++j])
	s[i].sQ = double(c[++j])
	s[i].U = double(c[++j])
	;
	s[i].sU = double(c[++j])
	s[i].nHWP = fix(c[++j])
	s[i].UF = long(c[++j])
	;
	s[i].ID_2mass = long(c[++j])
	s[i].desig_2mass = c[++j]
	;
	s[i].RA_2mass = double(c[++j])
	s[i].Dec_2mass = double(c[++j])
	s[i].J_2mass = double(c[++j])
	s[i].sJ2mass = double(c[++j])
	s[i].H_2mass = double(c[++j])
	s[i].sH2mass = double(c[++j])
	s[i].K_2mass = double(c[++j])
	s[i].sK2mass = double(c[++j])
	;
	s[i].b36mag = double(c[++j])
	s[i].e_b36mag = double(c[++j])
	s[i].b45mag = double(c[++j])
	s[i].e_b45mag = double(c[++j])
	s[i].b58mag = double(c[++j])
	s[i].e_b58mag = double(c[++j])
	s[i].b80mag = double(c[++j])
	s[i].e_b80mag = double(c[++j])
	;
	i++
	;
	loop_end:
ENDWHILE
;
the_end:
;
FREE_LUN, lu_in
;
rpc_struct = {s: s, pol_head: pol_head}
;
return, rpc_struct
;
end
